.. title:: User guide : contents

.. _user_guide:

==========
User guide
==========

Under construction
------------------

This user guide is under construction. Please be patient while we update it
or suggest your own edits by `opening an issue
<https://github.com/richford/AFQ-Insight/issues>`_.

In the meantime, take a look at our examples `examples
<auto_examples/index.html>`_ to see AFQ-Insight in action.
